-- Function Tally.parseItemLink
--
-- Takes in an itemLink string and returns
-- the itemID from that string

function Tally.parseItemLink(itemLink)
  local _, itemId = strsplit(":", itemLink)
  return itemId
end -- function Tally.parseItemLink

-- Function Tally.parseLootEvent
--
-- a loot event has occured
-- parse the loot

function Tally.parseLootEvent()
  -- find how many items are looted
  local numItems = GetNumLootItems()
  
  -- for each looted item
  for index = 1, numItems do
    local lootSources = {GetLootSourceInfo(index)}
    local lootSlotLink = GetLootSlotLink(index)
    local lootSourceTable = {}
    
    if (lootSlotLink ~= nil) then
    
      local itemId = Tally.parseItemLink(lootSlotLink)
    
      -- build the loot source table

      local flag = false
      local sourceIndex = 1
    
      repeat
        local lootSource = lootSources[sourceIndex];
        if (lootSource == nil) then
          flag = true
        else
          sourceIndex = sourceIndex + 1;
      
          -- parse the loot source index to get the mob number
          local mobId, mobType = Tally.ParseGUID(lootSource)
      
          if (mobType == "NPC") then
            local lootAmount = lootSources[sourceIndex];
            sourceIndex = sourceIndex + 1;
     
            lootSourceTable[mobId] = lootAmount
          end -- if
        end -- if
      until flag == true -- repeat
      Tally.record_item_loot_by_mob(itemId, lootSourceTable)
    end -- if
  end -- for
end -- function Tally.parseLootEvent

-- test function
function Tally.test(itemId, itemTable)
  Tally.printTable(itemTable)
end -- function Tally.test

-- print a table
function Tally.printTable(incomingTable)
  for k, v in pairs(incomingTable) do
    print(k .. " <--> " .. v)
  end -- for
end -- function Tally.printTable
